@@ -1,38 +1,5 @@
 package config
 
-var websiteCategories = []string{
-	"ALDR",
-	"ANON",
-	"COMM",
-	"COMT",
-	"CTRL",
-	"CULTR",
-	"DATE",
-	"ECON",
-	"ENV",
-	"FILE",
-	"GAME",
-	"GMB",
-	"GOVT",
-	"GRP",
-	"HACK",
-	"HATE",
-	"HOST",
-	"HUMR",
-	"IGO",
-	"LGBT",
-	"MILX",
-	"MMED",
-	"NEWS",
-	"POLR",
-	"PORN",
-	"PROV",
-	"PUBH",
-	"REL",
-	"SRCH",
-	"XED",
-}
-
 // Sharing settings
 type Sharing struct {
 	UploadResults bool `json:"upload_results"`
@@ -45,6 +12,7 @@ type Advanced struct {
 
 // Nettests related settings
 type Nettests struct {
+	WebsitesMaxRuntime           int64    `json:"websites_max_runtime"`
 	WebsitesURLLimit             int64    `json:"websites_url_limit"`
 	WebsitesEnabledCategoryCodes []string `json:"websites_enabled_category_codes"`
 }
