@@ -37,6 +37,7 @@ var All = map[string]Group{
 			FacebookMessenger{},
 			Telegram{},
 			WhatsApp{},
+			Signal{},
 		},
 		UnattendedOK: true,
 	},
@@ -49,4 +50,11 @@ var All = map[string]Group{
 		},
 		UnattendedOK: true,
 	},
+	"experimental": {
+		Label: "Experimental Nettests",
+		Nettests: []Nettest{
+			DNSCheck{},
+			STUNReachability{},
+		},
+	},
 }
