@@ -2,15 +2,15 @@ package urlgetter
 
 import (
 	"context"
+	"io/ioutil"
 	"net/url"
-	"path/filepath"
 	"time"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/tunnel"
 	"github.com/ooni/probe-cli/v3/internal/engine/model"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/archival"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/errorx"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
+	"github.com/ooni/probe-cli/v3/internal/engine/tunnel"
 )
 
 // The Getter gets the specified target in the context of the
@@ -34,6 +34,9 @@ type Getter struct {
 	// Target is the thing to measure in this run. This field must
 	// be set otherwise the code won't know what to do.
 	Target string
+
+	// testIOUtilTempDir allows us to mock ioutil.TempDir
+	testIOUtilTempDir func(dir, pattern string) (string, error)
 }
 
 // Get performs the action described by g using the given context
@@ -80,6 +83,14 @@ func (g Getter) Get(ctx context.Context) (TestKeys, error) {
 	return tk, err
 }
 
+// ioutilTempDir calls either g.testIOUtilTempDir or ioutil.TempDir
+func (g Getter) ioutilTempDir(dir, pattern string) (string, error) {
+	if g.testIOUtilTempDir != nil {
+		return g.testIOUtilTempDir(dir, pattern)
+	}
+	return ioutil.TempDir(dir, pattern)
+}
+
 func (g Getter) get(ctx context.Context, saver *trace.Saver) (TestKeys, error) {
 	tk := TestKeys{
 		Agent:  "redirect",
@@ -94,10 +105,19 @@ func (g Getter) get(ctx context.Context, saver *trace.Saver) (TestKeys, error) {
 	// start tunnel
 	var proxyURL *url.URL
 	if g.Config.Tunnel != "" {
-		tun, err := tunnel.Start(ctx, tunnel.Config{
-			Name:    g.Config.Tunnel,
-			Session: g.Session,
-			WorkDir: filepath.Join(g.Session.TempDir(), "urlgetter-tunnel"),
+		// Every new instance of the tunnel goes into a separate
+		// directory within the temporary directory. Calling
+		// Session.Close will delete such a directory.
+		tundir, err := g.ioutilTempDir(g.Session.TempDir(), "urlgetter-tunnel-")
+		if err != nil {
+			return tk, err
+		}
+		tun, err := tunnel.Start(ctx, &tunnel.Config{
+			Name:      g.Config.Tunnel,
+			Session:   g.Session,
+			TorArgs:   g.Session.TorArgs(),
+			TorBinary: g.Session.TorBinary(),
+			TunnelDir: tundir,
 		})
 		if err != nil {
 			return tk, err
