@@ -5,6 +5,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"net/url"
 	"time"
 
 	engine "github.com/ooni/probe-cli/v3/internal/engine"
@@ -69,17 +70,31 @@ func (r *Runner) hasUnsupportedSettings(logger *ChanLogger) bool {
 	return false
 }
 
-func (r *Runner) newsession(logger *ChanLogger) (*engine.Session, error) {
+func (r *Runner) newsession(ctx context.Context, logger *ChanLogger) (*engine.Session, error) {
 	kvstore, err := engine.NewFileSystemKVStore(r.settings.StateDir)
 	if err != nil {
 		return nil, err
 	}
+
+	// TODO(bassosimone): write tests for this functionality
+	// See https://github.com/ooni/probe/issues/1465.
+	var proxyURL *url.URL
+	if r.settings.Proxy != "" {
+		var err error
+		proxyURL, err = url.Parse(r.settings.Proxy)
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	config := engine.SessionConfig{
 		KVStore:         kvstore,
 		Logger:          logger,
+		ProxyURL:        proxyURL,
 		SoftwareName:    r.settings.Options.SoftwareName,
 		SoftwareVersion: r.settings.Options.SoftwareVersion,
 		TempDir:         r.settings.TempDir,
+		TunnelDir:       r.settings.TunnelDir,
 	}
 	if r.settings.Options.ProbeServicesBaseURL != "" {
 		config.AvailableProbeServices = []model.Service{{
@@ -87,7 +102,7 @@ func (r *Runner) newsession(logger *ChanLogger) (*engine.Session, error) {
 			Address: r.settings.Options.ProbeServicesBaseURL,
 		}}
 	}
-	return engine.NewSession(config)
+	return engine.NewSession(ctx, config)
 }
 
 func (r *Runner) contextForExperiment(
@@ -120,7 +135,7 @@ func (r *Runner) Run(ctx context.Context) {
 		return
 	}
 	r.emitter.Emit(statusStarted, eventEmpty{})
-	sess, err := r.newsession(logger)
+	sess, err := r.newsession(ctx, logger)
 	if err != nil {
 		r.emitter.EmitFailureStartup(err.Error())
 		return
